/**
 * Beispielsklasse zur Generierung von GML.
 *
 * @author: Thomas Brinkhoff
 * @version: 1.00
 */

import oracle.sql.STRUCT;
import oracle.spatial.geometry.JGeometry;

public class GenerateGML {

/**
 * Umwandlung einer SDO_GEOMETRY in GML.
 */
public static String toGML (STRUCT spatialObj) {
	try {
		JGeometry geom = JGeometry.load(spatialObj);
		// Fall: einzelner Punkt
		if (geom.isPoint()) {
			double c[] = geom.getPoint();
			return "<Point><pos>"+c[0]+" "+c[1]+"</pos></Point>";
		}
		// Fall: Linie
		else if (geom.getType() == JGeometry.GTYPE_CURVE) {
			int elemInfo[] = geom.getElemInfo();
			// Fall: nicht-zusammensetzter Linienzug
			if (elemInfo.length == 3) {
				double ord[] = geom.getOrdinatesArray();
				// Fall: einfacher Streckenzug
				if (! geom.hasCircularArcs()) {
					StringBuffer res = new StringBuffer("<LineString>\n  <posList>");
					for (int i=0; i<ord.length; i++)
						res.append(ord[i]+" ");
					res.append("</posList>\n</LineString>");
					return res.toString();
				}
			}
			// Fall: zusammengesetzte Linienzge
			else {
				StringBuffer res = new StringBuffer("<CompositeCurve>\n");
				Object ordArrays [] = geom.getOrdinatesOfElements();
				// Bestandteile des Linienzugs bearbeiten
				for (int seg=0; seg<ordArrays.length; seg++) {
					res.append("  <curveMember>\n");
					double[] ord = (double[])ordArrays[seg];
					// Fall: Teilstck ist Streckenzug
					if (elemInfo[seg*3+5] == 1) {
						res.append("    <LineString>\n      <posList>");
						for (int i=0; i<ord.length; i++)
							res.append(ord[i]+" ");
						res.append("</posList>\n    </LineString>\n");
					}
					// Fall: Teilstck besteht aus Kreisbgen
					else {
						res.append("    <Curve><segments><ArcString>\n      <posList>");
						for (int i=0; i<ord.length; i++)
							res.append(ord[i]+" ");
						res.append("</posList>\n    </ArcString></segments></Curve>\n");
					}
					res.append("  </curveMember>\n");
				}
				res.append("</CompositeCurve>");
				return res.toString();
			}
		}
		return "<Error>Typ "+geom.getType()+" wird z.Zt. nicht untersttzt.</Error>";
	} // try

	catch (Exception ex) {
		return "<Error>"+ex+"</Error>";
	}
}
}
