import static gdbutil.ConnectionParameters.*;

import java.util.HashMap;

import org.geotools.data.DataStore;
import org.geotools.data.FeatureReader;
import org.geotools.data.FeatureResults;
import org.geotools.data.FeatureSource;
import org.geotools.data.oracle.OracleDataStoreFactory;
import org.geotools.feature.Feature;

import com.vividsolutions.jts.geom.Geometry;

/**
 * Beispielsprogramm zur Demonstration des Zugriffs mit Geotools 2.
 *
 * @author: Thomas Brinkhoff
 * @version: 1.00
 */
public class GeotoolsExample {

	public static void main(String[] args) {
		try {
			// Verbindung spezifizieren
	        HashMap<String,String> m = new HashMap<String,String>();
	        m.put("dbtype","oracle");
	        m.put("host",DBHOST);
	        m.put("port",DBPORT);
	        m.put("instance",DBNAME);
	        m.put("user",DBUSER);
	        m.put("passwd",DBPASSWORD);
	        m.put("schema",DBUSER);
	        // Datastore anlegen
	        OracleDataStoreFactory f = new OracleDataStoreFactory();
	        DataStore store = f.createDataStore(m);
	        // Tabelle auswhlen und einlesen
			FeatureSource fSource = store.getFeatureSource("ORTSNETZE");
			System.out.println(fSource.getSchema());
			FeatureResults res = fSource.getFeatures();
			FeatureReader reader = res.reader();
			Geometry geom = null;
			while (reader.hasNext()) {
				Feature obj = reader.next();
				geom = obj.getDefaultGeometry();
				if (geom != null)
					System.out.println(obj.getAttribute("NAME")+" "+obj.getID()+": "+geom.getArea());
			}
			reader.close();
			/*
			// Objekt erzeugen
			Object data[] = new Object[]{"Helgoland",geom};
			org.geotools.feature.Feature newFeature = fSource.getSchema().create(data,"04725");
			org.geotools.data.FeatureReader newReader = org.geotools.data.DataUtilities.reader(new Feature[] { newFeature} );
			// Im FeatureStore speichern
			org.geotools.data.FeatureStore featureStore = (org.geotools.data.FeatureStore) fSource;
			featureStore.addFeatures(newReader);
			// Transaktion durchfhren
			org.geotools.data.Transaction t = featureStore.getTransaction();
			t.commit();
			t.close();
			*/	
		}
		// Fehlerbehandlung
		catch (Exception ex) {
			System.err.println("GeotoolsExample.main: "+ex);
		}
	}
}
